import DescriptionItem from '@/components/DescriptionItem';
import services from '@/services';
import { useModel } from '@umijs/max';
import { Flex, Space } from 'antd';
import React, { useEffect, useState } from 'react';
import LineCharts from '../LineCharts';
import styles from './index.less';
import CountUp from 'react-countup';

const Advertisement: React.FC = () => {
  const { initialState } = useModel('@@initialState');
  const { areaId } = initialState;

  const [eventCount, setEventCount] = useState(0);

  const [eventChartData, setEventChartData] = useState([]);

  const commonValueStyle = {
    background: 'linear-gradient(180deg, #AAFFF6 0%, #25BBFF 100%)',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
    fontFamily: 'D-DIN',
    fontSize: '36px',
    fontWeight: 700,
    lineHeight: 1.1,
  };

  const commonLabelStyle = {
    color: '#BCCEE9',
    // fontFamily: '微软雅黑',
    fontSize: '20px',
    fontWeight: 400,
    lineHeight: 1.1,
  };

  const labelStyle = {
    ...commonLabelStyle,
    width: '85%',
  };

  const commonUnitStyle = {
    color: '#BCCEE9',
    // fontFamily: '微软雅黑',
    fontSize: '20px',
    fontWeight: 400,
    lineHeight: 1.1,
  };

  const getData = () => {
    const params = {
      industry: '01',
      dateType: 'today',
      objectId: areaId,
    };
    services.Physicalsign.getNormalEventCountApi(params).then((res: any) => {
      console.log(res);
      if (res.code === 200) {
        setEventCount(res.data?.problemCount);
      }
    });
  };

  const getEchartsData = () => {
    const params = {
      industry: '01',
      dateType: 'month',
      objectId: areaId,
    };
    services.Physicalsign.getNormalEventTrendApi(params).then((res: any) => {
      console.log(res);
      if (res.code === 200) {
        setEventChartData(res.data);
      }
    });
  };

  useEffect(() => {
    getData();
    getEchartsData();
  }, []);

  return (
    <div className={styles.container}>
      <Flex vertical gap={15}>
        <Space size={15}>
          <span className={styles.label} style={commonLabelStyle}>
            今日发现问题
          </span>
          <CountUp
            className={styles.value}
            end={Number(eventCount)}
            style={commonValueStyle}
            preserveValue
            decimals={0}
          />
          {/* <div style={commonValueStyle}>--</div> */}
          <span className={styles.unit} style={commonUnitStyle}>
            件
          </span>
        </Space>
        <div>
          <LineCharts data={eventChartData || []} />
        </div>
        <Flex justify="space-between">
          <DescriptionItem
            value={208.93}
            name="共享单车投放数"
            unit="万辆"
            valueStyle={commonValueStyle}
            labelStyle={commonLabelStyle}
            unitStyle={commonUnitStyle}
            decimals={2}
          />
        </Flex>
      </Flex>
    </div>
  );
};

export default Advertisement;
